## Version 0.5.2

This release includes several improvements to the build process, testing, and documentation.

### New Features

- Dockerfile has been updated to use pixi, which simplifies the build process and reduces dependencies (4ccd5c9) (Eric Ma)
- The docs build and deploy process has been simplified with the use of pixi run build-docs (04cde63) (Eric Ma)
- The GitHub workflow for setting up the pixi environment has been updated (a38145f) (Eric Ma)
- The prepare-commit-msg hook has been improved to handle commit messages more reliably (75dca4c) (Eric Ma)
- The LlamaBot configuration tutorial has been improved for better readability and clarity (82b1177) (Eric Ma)

### Bug Fixes

- The test\_structuredbot.py file has been updated to use pytest and reduce the number of attempts from 50 to 3 (ac5b1aa) (Eric Ma)
- The git.py file has been fixed to improve the prepare-commit-msg hook and check if a commit message is provided before running llamabot git compose (c5e9fa1) (Eric Ma)

### Deprecations

- The miniconda setup in the GitHub workflow has been replaced with the pixi environment setup (a38145f) (Eric Ma)
- The manual build steps in the docs workflow have been replaced with pixi run build-docs (04cde63) (Eric Ma)
- The mamba env create command has been replaced with pixi install in the Dockerfile (4ccd5c9) (Eric Ma)
- The deploy directory in the docs workflow has been updated from ./docs to ./site (04cde63) (Eric Ma)
- The documentation for installing the commit message hook and auto-composing commit messages has been updated (579edc4) (Eric Ma)
